| Title: | Random Graphical Model Estimation under L0 Penalty |
|---|---|
| Description: | Provides functions for estimating sparse precision matrices using a random graphical model framework under an L0-style penalty. The method evaluates candidate theta values and returns both continuous and binary precision matrices representing inferred network structures. |
| Authors: | Mahdieh Farzin Asanjan [aut, cre], Vilda Purutcuoglu [aut], Ernst Wit [aut] |
| Maintainer: | Mahdieh Farzin Asanjan <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.1 |
| Built: | 2026-06-08 07:15:54 UTC |
| Source: | https://github.com/cran/rgml0 |
Estimates sparse precision matrices from a covariance matrix using an iterative sparse-step approximation under an L0-style penalty. The method evaluates a grid of theta values and returns both continuous and binary precision matrices representing the inferred network structure.
rgml0( S, theta.jump = 0.1, n.iter = 5, gamma0 = 1000, gammastop = 1e-04, IMsteps = 2, gammastep = 1.1, force.zero = TRUE, threshold = 1e-07, use_diag = FALSE )rgml0( S, theta.jump = 0.1, n.iter = 5, gamma0 = 1000, gammastop = 1e-04, IMsteps = 2, gammastep = 1.1, force.zero = TRUE, threshold = 1e-07, use_diag = FALSE )
S |
A numeric covariance matrix. |
theta.jump |
Step size for candidate theta values. |
n.iter |
Number of inner iterations. |
gamma0 |
Initial gamma value. |
gammastop |
Stopping value for gamma. |
IMsteps |
Currently unused. |
gammastep |
Factor used to decrease gamma. |
force.zero |
Logical flag (currently unused). |
threshold |
Threshold for binarizing the precision matrix. |
use_diag |
Logical flag (currently unused). |
A list where each element contains:
Estimated precision matrix.
Thresholded binary matrix.
Theta value used.
Index of theta.
S <- diag(3) out <- rgml0(S, theta.jump = 0.4, n.iter = 1, gamma0 = 1, gammastop = 0.1, gammastep = 2) length(out)S <- diag(3) out <- rgml0(S, theta.jump = 0.4, n.iter = 1, gamma0 = 1, gammastop = 0.1, gammastep = 2) length(out)